@@ -3,12 +3,14 @@
  *
  * Copyright (C) 2010-2015  Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>
  *
- * Version: 1.0.34   2015/05/05
+ * Version: 1.0.35   2015/11/11
  */
 
 #include <linux/version.h>
 #include <linux/security.h>
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 1, 0) && !defined(SECURITY_NAME_MAX)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 7, 0)
+#include "lsm-4.7.c"
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(4, 2, 0)
 #include "lsm-4.2.c"
 #elif LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 29)
 #include "lsm-2.6.29.c"
